@@ -32,7 +32,7 @@ class BlockParserTests(unittest.TestCase):
 
     def test_parses_simple_elements(self):
         self.parser.parse_blocks(
-            ['SCENARIO foo', 'GIVEN bar',
+            ['SCENARIO foo', 'ASSUMING something', 'GIVEN bar',
              'WHEN foobar\nTHEN yoyo\nFINALLY yay\nAND yeehaa'])
 
         self.assertEqual(len(self.parser.scenarios), 1)
@@ -40,17 +40,19 @@ class BlockParserTests(unittest.TestCase):
 
         scenario = self.parser.scenarios[0]
         self.assertEqual(scenario.name, 'foo')
-        self.assertEqual(len(scenario.steps), 5)
-        self.assertEqual(scenario.steps[0].what, 'GIVEN')
-        self.assertEqual(scenario.steps[0].text, 'bar')
-        self.assertEqual(scenario.steps[1].what, 'WHEN')
-        self.assertEqual(scenario.steps[1].text, 'foobar')
-        self.assertEqual(scenario.steps[2].what, 'THEN')
-        self.assertEqual(scenario.steps[2].text, 'yoyo')
-        self.assertEqual(scenario.steps[3].what, 'FINALLY')
-        self.assertEqual(scenario.steps[3].text, 'yay')
+        self.assertEqual(len(scenario.steps), 6)
+        self.assertEqual(scenario.steps[0].what, 'ASSUMING')
+        self.assertEqual(scenario.steps[0].text, 'something')
+        self.assertEqual(scenario.steps[1].what, 'GIVEN')
+        self.assertEqual(scenario.steps[1].text, 'bar')
+        self.assertEqual(scenario.steps[2].what, 'WHEN')
+        self.assertEqual(scenario.steps[2].text, 'foobar')
+        self.assertEqual(scenario.steps[3].what, 'THEN')
+        self.assertEqual(scenario.steps[3].text, 'yoyo')
         self.assertEqual(scenario.steps[4].what, 'FINALLY')
-        self.assertEqual(scenario.steps[4].text, 'yeehaa')
+        self.assertEqual(scenario.steps[4].text, 'yay')
+        self.assertEqual(scenario.steps[5].what, 'FINALLY')
+        self.assertEqual(scenario.steps[5].text, 'yeehaa')
 
     def test_normalises_whitespace(self):
         self.parser.parse_blocks(['SCENARIO   foo   bar   '])
