@@ -67,9 +67,10 @@ class MarkdownParser(object):
         ext = ParseScenarioTestBlocks()
         f = StringIO.StringIO()
         markdown.markdown(text, output=f, extensions=[ext])
-        self.blocks = ext.blocks
+        self.blocks.extend(ext.blocks)
+        return ext.blocks
 
     def parse_file(self, filename): # pragma: no cover
         with open(filename) as f:
-            self.parse_string(f.read())
+            return self.parse_string(f.read())
 
